@@ -13,8 +13,6 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- * $Id: iLBC_decode.c,v 1.3 2008/10/02 12:00:56 steveu Exp $
  */
 
 /*! \file */
@@ -64,91 +62,6 @@ __inline__ long int rint(double x)
 }
 #endif
 
-/*----------------------------------------------------------------*
- *  Initiation of decoder instance.
- *---------------------------------------------------------------*/
-ilbc_decode_state_t *ilbc_decode_init(ilbc_decode_state_t *s,
-                                      int mode,
-                                      int use_enhancer)
-{
-    int i;
-
-    if (mode != 30  &&  mode != 20)
-        return NULL;
-
-    if (s == NULL)
-    {
-        if ((s = (ilbc_decode_state_t *) malloc(sizeof(*s))) == NULL)
-            return NULL;
-    }
-    memset(s, 0, sizeof(*s));
-
-    s->mode = mode;
-    if (mode == 30)
-    {
-        s->blockl = ILBC_BLOCK_LEN_30MS;
-        s->nsub = NSUB_30MS;
-        s->nasub = NASUB_30MS;
-        s->lpc_n = LPC_N_30MS;
-        s->no_of_bytes = ILBC_NO_OF_BYTES_30MS;
-        s->state_short_len = STATE_SHORT_LEN_30MS;
-        /* ULP init */
-        s->ULP_inst = &ULP_30msTbl;
-    }
-    else
-    {
-        s->blockl = ILBC_BLOCK_LEN_20MS;
-        s->nsub = NSUB_20MS;
-        s->nasub = NASUB_20MS;
-        s->lpc_n = LPC_N_20MS;
-        s->no_of_bytes = ILBC_NO_OF_BYTES_20MS;
-        s->state_short_len = STATE_SHORT_LEN_20MS;
-        /* ULP init */
-        s->ULP_inst = &ULP_20msTbl;
-    }
-
-    memset(s->syntMem, 0, ILBC_LPC_FILTERORDER*sizeof(float));
-    memcpy(s->lsfdeqold, lsfmeanTbl, ILBC_LPC_FILTERORDER*sizeof(float));
-
-    memset(s->old_syntdenum,
-           0,
-           ((ILBC_LPC_FILTERORDER + 1)*ILBC_NUM_SUB_MAX)*sizeof(float));
-    for (i = 0;  i < ILBC_NUM_SUB_MAX;  i++)
-        s->old_syntdenum[i*(ILBC_LPC_FILTERORDER + 1)] = 1.0f;
-
-    s->last_lag = 20;
-
-    s->prevLag = 120;
-    s->per = 0.0;
-    s->consPLICount = 0;
-    s->prevPLI = 0;
-    s->prevLpc[0] = 1.0f;
-    memset(s->prevLpc + 1, 0, ILBC_LPC_FILTERORDER*sizeof(float));
-    memset(s->prevResidual, 0, ILBC_BLOCK_LEN_MAX*sizeof(float));
-    s->seed = 777;
-    memset(s->hpomem, 0, 4*sizeof(float));
-
-    s->use_enhancer = use_enhancer;
-    memset(s->enh_buf, 0, ENH_BUFL*sizeof(float));
-    for (i = 0;  i < ENH_NBLOCKS_TOT;  i++)
-        s->enh_period[i] = 40.0f;
-
-    s->prev_enh_pl = 0;
-
-    return s;
-}
-/*- End of function --------------------------------------------------------*/
-
-int ilbc_decode_release(ilbc_decode_state_t *s)
-{
-    free(s);
-    return 0;
-}
-/*- End of function --------------------------------------------------------*/
-
-/*----------------------------------------------------------------*
- *  frame residual decoder function (subrutine to iLBC_decode)
- *---------------------------------------------------------------*/
 static void Decode(ilbc_decode_state_t *iLBCdec_inst,  /* (i/o) the decoder state structure */
                    float *decresidual,                 /* (o) decoded residual frame */
                    int start,                          /* (i) location of start state */
@@ -314,9 +227,6 @@ static void Decode(ilbc_decode_state_t *iLBCdec_inst,  /* (i/o) the decoder stat
 }
 /*- End of function --------------------------------------------------------*/
 
-/*----------------------------------------------------------------*
- *  main decoder function
- *---------------------------------------------------------------*/
 static void ilbc_decode_frame(ilbc_decode_state_t *iLBCdec_inst, /* (i/o) the decoder state structure */
                               float decblock[],                  /* (o) decoded signal block */
                               const uint8_t bytes[],             /* (i) encoded signal bits */
@@ -602,10 +512,10 @@ static void ilbc_decode_frame(ilbc_decode_state_t *iLBCdec_inst, /* (i/o) the de
 }
 /*- End of function --------------------------------------------------------*/
 
-int ilbc_decode(ilbc_decode_state_t *s,     /* (i/o) the decoder state structure */
-                int16_t amp[],              /* (o) decoded signal block */
-                const uint8_t bytes[],      /* (i) encoded signal bits */
-                int len)
+ILBC_DECLARE(int) ilbc_decode(ilbc_decode_state_t *s,     /* (i/o) the decoder state structure */
+                              int16_t amp[],              /* (o) decoded signal block */
+                              const uint8_t bytes[],      /* (i) encoded signal bits */
+                              int len)
 {
     int i;
     int j;
@@ -632,9 +542,9 @@ int ilbc_decode(ilbc_decode_state_t *s,     /* (i/o) the decoder state structure
 }
 /*- End of function --------------------------------------------------------*/
 
-int ilbc_fillin(ilbc_decode_state_t *s,     /* (i/o) the decoder state structure */
-                int16_t amp[],              /* (o) decoded signal block */
-                int len)
+ILBC_DECLARE(int) ilbc_fillin(ilbc_decode_state_t *s,     /* (i/o) the decoder state structure */
+                              int16_t amp[],              /* (o) decoded signal block */
+                              int len)
 {
     int i;
     int j;
@@ -660,4 +570,83 @@ int ilbc_fillin(ilbc_decode_state_t *s,     /* (i/o) the decoder state structure
     return i;
 }
 /*- End of function --------------------------------------------------------*/
+
+ILBC_DECLARE(ilbc_decode_state_t *) ilbc_decode_init(ilbc_decode_state_t *s,
+                                                     int mode,
+                                                     int use_enhancer)
+{
+    int i;
+
+    if (mode != 30  &&  mode != 20)
+        return NULL;
+
+    if (s == NULL)
+    {
+        if ((s = (ilbc_decode_state_t *) malloc(sizeof(*s))) == NULL)
+            return NULL;
+    }
+    memset(s, 0, sizeof(*s));
+
+    s->mode = mode;
+    if (mode == 30)
+    {
+        s->blockl = ILBC_BLOCK_LEN_30MS;
+        s->nsub = NSUB_30MS;
+        s->nasub = NASUB_30MS;
+        s->lpc_n = LPC_N_30MS;
+        s->no_of_bytes = ILBC_NO_OF_BYTES_30MS;
+        s->state_short_len = STATE_SHORT_LEN_30MS;
+        /* ULP init */
+        s->ULP_inst = &ULP_30msTbl;
+    }
+    else
+    {
+        s->blockl = ILBC_BLOCK_LEN_20MS;
+        s->nsub = NSUB_20MS;
+        s->nasub = NASUB_20MS;
+        s->lpc_n = LPC_N_20MS;
+        s->no_of_bytes = ILBC_NO_OF_BYTES_20MS;
+        s->state_short_len = STATE_SHORT_LEN_20MS;
+        /* ULP init */
+        s->ULP_inst = &ULP_20msTbl;
+    }
+
+    memset(s->syntMem, 0, ILBC_LPC_FILTERORDER*sizeof(float));
+    memcpy(s->lsfdeqold, lsfmeanTbl, ILBC_LPC_FILTERORDER*sizeof(float));
+
+    memset(s->old_syntdenum,
+           0,
+           ((ILBC_LPC_FILTERORDER + 1)*ILBC_NUM_SUB_MAX)*sizeof(float));
+    for (i = 0;  i < ILBC_NUM_SUB_MAX;  i++)
+        s->old_syntdenum[i*(ILBC_LPC_FILTERORDER + 1)] = 1.0f;
+
+    s->last_lag = 20;
+
+    s->prevLag = 120;
+    s->per = 0.0;
+    s->consPLICount = 0;
+    s->prevPLI = 0;
+    s->prevLpc[0] = 1.0f;
+    memset(s->prevLpc + 1, 0, ILBC_LPC_FILTERORDER*sizeof(float));
+    memset(s->prevResidual, 0, ILBC_BLOCK_LEN_MAX*sizeof(float));
+    s->seed = 777;
+    memset(s->hpomem, 0, 4*sizeof(float));
+
+    s->use_enhancer = use_enhancer;
+    memset(s->enh_buf, 0, ENH_BUFL*sizeof(float));
+    for (i = 0;  i < ENH_NBLOCKS_TOT;  i++)
+        s->enh_period[i] = 40.0f;
+
+    s->prev_enh_pl = 0;
+
+    return s;
+}
+/*- End of function --------------------------------------------------------*/
+
+ILBC_DECLARE(int) ilbc_decode_release(ilbc_decode_state_t *s)
+{
+    free(s);
+    return 0;
+}
+/*- End of function --------------------------------------------------------*/
 /*- End of file ------------------------------------------------------------*/
