@@ -13,8 +13,6 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- * $Id: iLBC_encode.c,v 1.3 2008/10/02 12:00:56 steveu Exp $
  */
 
 /*! \file */
@@ -42,65 +40,6 @@
 #include "anaFilter.h"
 #include "syntFilter.h"
 
-/*----------------------------------------------------------------*
- *  Initiation of encoder instance.
- *---------------------------------------------------------------*/
-ilbc_encode_state_t *ilbc_encode_init(ilbc_encode_state_t *s, int mode)
-{
-    if (mode != 30  &&  mode != 20)
-        return NULL;
-
-    if (s == NULL)
-    {
-        if ((s = (ilbc_encode_state_t *) malloc(sizeof(*s))) == NULL)
-            return NULL;
-    }
-    memset(s, 0, sizeof(*s));
-
-    s->mode = mode;
-    if (mode == 30)
-    {
-        s->blockl = ILBC_BLOCK_LEN_30MS;
-        s->nsub = NSUB_30MS;
-        s->nasub = NASUB_30MS;
-        s->lpc_n = LPC_N_30MS;
-        s->no_of_bytes = ILBC_NO_OF_BYTES_30MS;
-        s->state_short_len = STATE_SHORT_LEN_30MS;
-        /* ULP init */
-        s->ULP_inst = &ULP_30msTbl;
-    }
-    else
-    {
-        s->blockl = ILBC_BLOCK_LEN_20MS;
-        s->nsub = NSUB_20MS;
-        s->nasub = NASUB_20MS;
-        s->lpc_n = LPC_N_20MS;
-        s->no_of_bytes = ILBC_NO_OF_BYTES_20MS;
-        s->state_short_len = STATE_SHORT_LEN_20MS;
-        /* ULP init */
-        s->ULP_inst = &ULP_20msTbl;
-    }
-
-    memset(s->anaMem, 0, ILBC_LPC_FILTERORDER*sizeof(float));
-    memcpy(s->lsfold, lsfmeanTbl, ILBC_LPC_FILTERORDER*sizeof(float));
-    memcpy(s->lsfdeqold, lsfmeanTbl, ILBC_LPC_FILTERORDER*sizeof(float));
-    memset(s->lpc_buffer, 0, (LPC_LOOKBACK + ILBC_BLOCK_LEN_MAX)*sizeof(float));
-    memset(s->hpimem, 0, 4*sizeof(float));
-
-    return s;
-}
-/*- End of function --------------------------------------------------------*/
-
-int ilbc_encode_release(ilbc_encode_state_t *s)
-{
-    free(s);
-    return 0;
-}
-/*- End of function --------------------------------------------------------*/
-
-/*----------------------------------------------------------------*
- *  main encoder function
- *---------------------------------------------------------------*/
 static int ilbc_encode_frame(ilbc_encode_state_t *iLBCenc_inst,     /* (i/o) the general encoder state */
                              uint8_t bytes[],                       /* (o) encoded data bits iLBC */
                              const float block[])                   /* (o) speech vector to encode */
@@ -508,10 +447,10 @@ static int ilbc_encode_frame(ilbc_encode_state_t *iLBCenc_inst,     /* (i/o) the
 }
 /*- End of function --------------------------------------------------------*/
 
-int ilbc_encode(ilbc_encode_state_t *s,     /* (i/o) the general encoder state */
-                uint8_t bytes[],            /* (o) encoded data bits iLBC */
-                const int16_t amp[],        /* (o) speech vector to encode */
-                int len)
+ILBC_DECLARE(int) ilbc_encode(ilbc_encode_state_t *s,     /* (i/o) the general encoder state */
+                              uint8_t bytes[],            /* (o) encoded data bits iLBC */
+                              const int16_t amp[],        /* (o) speech vector to encode */
+                              int len)
 {
     int i;
     int j;
@@ -528,4 +467,57 @@ int ilbc_encode(ilbc_encode_state_t *s,     /* (i/o) the general encoder state *
     return j;
 }
 /*- End of function --------------------------------------------------------*/
+
+ILBC_DECLARE(ilbc_encode_state_t *) ilbc_encode_init(ilbc_encode_state_t *s, int mode)
+{
+    if (mode != 30  &&  mode != 20)
+        return NULL;
+
+    if (s == NULL)
+    {
+        if ((s = (ilbc_encode_state_t *) malloc(sizeof(*s))) == NULL)
+            return NULL;
+    }
+    memset(s, 0, sizeof(*s));
+
+    s->mode = mode;
+    if (mode == 30)
+    {
+        s->blockl = ILBC_BLOCK_LEN_30MS;
+        s->nsub = NSUB_30MS;
+        s->nasub = NASUB_30MS;
+        s->lpc_n = LPC_N_30MS;
+        s->no_of_bytes = ILBC_NO_OF_BYTES_30MS;
+        s->state_short_len = STATE_SHORT_LEN_30MS;
+        /* ULP init */
+        s->ULP_inst = &ULP_30msTbl;
+    }
+    else
+    {
+        s->blockl = ILBC_BLOCK_LEN_20MS;
+        s->nsub = NSUB_20MS;
+        s->nasub = NASUB_20MS;
+        s->lpc_n = LPC_N_20MS;
+        s->no_of_bytes = ILBC_NO_OF_BYTES_20MS;
+        s->state_short_len = STATE_SHORT_LEN_20MS;
+        /* ULP init */
+        s->ULP_inst = &ULP_20msTbl;
+    }
+
+    memset(s->anaMem, 0, ILBC_LPC_FILTERORDER*sizeof(float));
+    memcpy(s->lsfold, lsfmeanTbl, ILBC_LPC_FILTERORDER*sizeof(float));
+    memcpy(s->lsfdeqold, lsfmeanTbl, ILBC_LPC_FILTERORDER*sizeof(float));
+    memset(s->lpc_buffer, 0, (LPC_LOOKBACK + ILBC_BLOCK_LEN_MAX)*sizeof(float));
+    memset(s->hpimem, 0, 4*sizeof(float));
+
+    return s;
+}
+/*- End of function --------------------------------------------------------*/
+
+ILBC_DECLARE(int) ilbc_encode_release(ilbc_encode_state_t *s)
+{
+    free(s);
+    return 0;
+}
+/*- End of function --------------------------------------------------------*/
 /*- End of file ------------------------------------------------------------*/
